@@ -93,7 +93,6 @@ static int read_sw_version_file(struct swupdate_cfg *sw)
 	return 0;
 }
 
-#ifdef CONFIG_LIBCONFIG
 static int versions_settings(void *setting, void *data)
 {
 	struct swupdate_cfg *sw = (struct swupdate_cfg *)data;
@@ -136,14 +135,6 @@ void get_sw_versions(swupdate_cfg_handle *handle, struct swupdate_cfg *sw)
 	/* If not found, fall back to a legacy file in the format "<image name> <version>" */
 	read_sw_version_file(sw);
 }
-#else
-
-void get_sw_versions(swupdate_cfg_handle  __attribute__ ((__unused__))*handle,
-			struct swupdate_cfg *sw)
-{
-	read_sw_version_file(sw);
-}
-#endif
 
 /*
  * convert a version string into a number
@@ -191,7 +182,7 @@ out:
 
 static const char ACCEPTED_CHARS[] = "0123456789.";
 
-static bool is_oldstyle_version(const char *version_string, __u64 *version_number)
+static bool is_numbered_version(const char *version_string, __u64 *version_number)
 {
 	const char *ver = version_string;
 	while (*ver)
@@ -220,8 +211,8 @@ int compare_versions(const char* left_version, const char* right_version)
 	__u64 left_u64;
 	__u64 right_u64;
 
-	if (is_oldstyle_version(left_version, &left_u64)
-	    && is_oldstyle_version(right_version, &right_u64))
+	if (is_numbered_version(left_version, &left_u64)
+	    && is_numbered_version(right_version, &right_u64))
 	{
 		DEBUG("Comparing old-style versions '%s' <-> '%s'",
 		      left_version, right_version);
