@@ -16,6 +16,9 @@
 #ifdef CONFIG_GUNZIP
 #include <zlib.h>
 #endif
+#ifdef CONFIG_XZ
+#include <lzma.h>
+#endif
 #ifdef CONFIG_ZSTD
 #include <zstd.h>
 #endif
@@ -24,7 +27,7 @@
 #include "cpiohdr.h"
 #include "swupdate.h"
 #include "util.h"
-#include "sslapi.h"
+#include "swupdate_crypto.h"
 #include "progress.h"
 
 #define MODULE_NAME "cpio"
@@ -69,6 +72,10 @@ static int _fill_buffer(int fd, unsigned char *buf, unsigned int nbytes, unsigne
 	while (nbytes > 0) {
 		len = read(fd, buf, nbytes);
 		if (len < 0) {
+			if (errno == EINTR) {
+				continue;
+			}
+
 			ERROR("Failure in stream %d: %s", fd, strerror(errno));
 			return -EFAULT;
 		}
@@ -305,14 +312,16 @@ static int decrypt_step(void *state, void *buffer, size_t size)
 			ret = swupdate_DECRYPT_update(s->dcrypt,
 				s->output, &s->outlen, s->input, inlen);
 		}
-		if (inlen == 0 || s->outlen == 0) {
+		if (inlen == 0) {
 			/*
 			 * Finalise the decryption. Further plaintext bytes may
 			 * be written at this stage.
 			 */
 			ret = swupdate_DECRYPT_final(s->dcrypt,
 				s->output, &s->outlen);
-			s->eof = true;
+			if (ret == 0) {
+				s->eof = true;
+			}
 		}
 		if (ret < 0) {
 			return ret;
@@ -332,7 +341,7 @@ static int decrypt_step(void *state, void *buffer, size_t size)
 	return 0;
 }
 
-#if defined(CONFIG_GUNZIP) || defined(CONFIG_ZSTD)
+#if defined(CONFIG_GUNZIP) || defined(CONFIG_ZSTD) || defined(CONFIG_XZ)
 typedef int (*DecompressStep)(void *state, void *buffer, size_t size);
 
 struct DecompressState {
@@ -391,6 +400,53 @@ static int gunzip_step(void *state, void *buffer, size_t size)
 
 #endif
 
+#ifdef CONFIG_XZ
+struct XzState {
+	lzma_stream strm;
+	bool initialized;
+};
+static int xz_step(void* state, void* buffer, size_t size)
+{
+	struct DecompressState *ds = (struct DecompressState *)state;
+	struct XzState *s = (struct XzState *)ds->impl_state;
+	lzma_ret ret;
+	int outlen = 0;
+	lzma_action action = LZMA_RUN;
+
+	s->strm.next_out = buffer;
+	s->strm.avail_out = size;
+
+	while (outlen == 0) {
+		if (s->strm.avail_in == 0) {
+			ret = ds->upstream_step(ds->upstream_state, ds->input, sizeof ds->input);
+			if (ret < 0) {
+				return ret;
+			} else if (ret == 0) {
+				ds->eof = true;
+			}
+			s->strm.avail_in = ret;
+			s->strm.next_in = ds->input;
+		}
+		if (ds->eof) {
+			break;
+		}
+
+		ret = lzma_code(&s->strm, action);
+		outlen = size - s->strm.avail_out;
+		if (ret == LZMA_STREAM_END) {
+			ds->eof = true;
+			break;
+		}
+		if (ret != LZMA_OK && ret != LZMA_BUF_ERROR) {
+			ERROR("xz failed (returned %d)", ret);
+			return -1;
+		}
+	}
+	return outlen;
+}
+
+#endif
+
 #ifdef CONFIG_ZSTD
 
 struct ZstdState {
@@ -438,7 +494,7 @@ static int zstd_step(void* state, void* buffer, size_t size)
 
 #endif
 
-static int hash_compare(struct swupdate_digest *dgst, unsigned char *hash)
+static int hash_compare(void *dgst, unsigned char *hash)
 {
 	/*
 	 * SHA256_HASH_LENGTH should be enough but openssl might write
@@ -478,6 +534,8 @@ int copyfile(struct swupdate_copy *args)
 	unsigned char *aes_key = NULL;
 	unsigned char *ivt = NULL;
 	unsigned char ivtbuf[AES_BLK_SIZE];
+	unsigned char aesbuf[AES_256_KEY_LEN];
+	char keylen = 0;
 
 	struct InputState input_state = {
 		.fdin = args->fdin,
@@ -496,7 +554,7 @@ int copyfile(struct swupdate_copy *args)
 		.outlen = 0, .eof = false
 	};
 
-#if defined(CONFIG_GUNZIP) || defined(CONFIG_ZSTD)
+#if defined(CONFIG_GUNZIP) || defined(CONFIG_ZSTD) || defined(CONFIG_XZ)
 	struct DecompressState decompress_state = {
 		.upstream_step = NULL, .upstream_state = NULL,
 		.impl_state = NULL
@@ -513,6 +571,12 @@ int copyfile(struct swupdate_copy *args)
 		.initialized = false,
 	};
 #endif
+#ifdef CONFIG_XZ
+	struct XzState xz_state = {
+		.strm = LZMA_STREAM_INIT,
+		.initialized = false,
+	};
+#endif
 #ifdef CONFIG_ZSTD
 	struct ZstdState zstd_state = {
 		.dctx = NULL,
@@ -548,7 +612,6 @@ int copyfile(struct swupdate_copy *args)
 	}
 
 	if (args->encrypted) {
-		aes_key = get_aes_key();
 		if (args->imgivt && strlen(args->imgivt)) {
 			if (!is_hex_str(args->imgivt) || ascii_to_bin(ivtbuf, sizeof(ivtbuf), args->imgivt)) {
 				ERROR("Invalid image ivt");
@@ -557,7 +620,25 @@ int copyfile(struct swupdate_copy *args)
 			ivt = ivtbuf;
 		} else
 			ivt = get_aes_ivt();
-		decrypt_state.dcrypt = swupdate_DECRYPT_init(aes_key, get_aes_keylen(), ivt);
+
+		if (args->imgaes && strlen(args->imgaes)) {
+				if (!is_hex_str(args->imgaes) || ascii_to_bin(aesbuf, sizeof(aesbuf), args->imgaes)) {
+					ERROR("Invalid image aes-key");
+					return -EINVAL;
+				}
+				aes_key = aesbuf;
+				keylen = strlen(args->imgaes) / 2;
+		} else {
+			/*
+			 * Only fall back to the default decryption key if the requested cipher matches.
+			 */
+			if (swupdate_get_decrypt_cipher() == args->cipher) {
+				aes_key = (unsigned char *)swupdate_get_decrypt_key();
+				keylen = swupdate_get_decrypt_keylen();
+			}
+		}
+
+		decrypt_state.dcrypt = swupdate_DECRYPT_init(aes_key, keylen, ivt, args->cipher);
 		if (!decrypt_state.dcrypt) {
 			ERROR("decrypt initialization failure, aborting");
 			ret = -EFAULT;
@@ -585,6 +666,19 @@ int copyfile(struct swupdate_copy *args)
 			decompress_state.impl_state = &gunzip_state;
 		} else
 #endif
+#ifdef CONFIG_XZ
+		if (args->compressed == COMPRESSED_XZ) {
+			if (lzma_stream_decoder(&xz_state.strm, UINT32_MAX,
+						0) != LZMA_OK) {
+				ERROR("(lzma_stream_decoder failed");
+				ret = -EFAULT;
+				goto copyfile_exit;
+			}
+			xz_state.initialized = true;
+			decompress_step = &xz_step;
+			decompress_state.impl_state = &xz_state;
+		} else
+#endif
 #ifdef CONFIG_ZSTD
 		if (args->compressed == COMPRESSED_ZSTD) {
 			if ((zstd_state.dctx = ZSTD_createDStream()) == NULL) {
@@ -630,7 +724,7 @@ int copyfile(struct swupdate_copy *args)
 		state = &decrypt_state;
 	}
 
-#if defined(CONFIG_GUNZIP) || defined(CONFIG_ZSTD)
+#if defined(CONFIG_GUNZIP) || defined(CONFIG_ZSTD) || defined(CONFIG_XZ)
 	if (args->compressed) {
 		decompress_state.upstream_step = step;
 		decompress_state.upstream_state = state;
@@ -641,6 +735,9 @@ int copyfile(struct swupdate_copy *args)
 
 	for (;;) {
 		ret = step(state, buffer, sizeof buffer);
+		if (ret == -EAGAIN) {
+			continue;
+		}
 		if (ret < 0) {
 			goto copyfile_exit;
 		}
@@ -699,6 +796,11 @@ copyfile_exit:
 		inflateEnd(&gunzip_state.strm);
 	}
 #endif
+#ifdef CONFIG_XZ
+	if (xz_state.initialized) {
+		lzma_end(&xz_state.strm);
+	}
+#endif
 #ifdef CONFIG_ZSTD
 	if (zstd_state.dctx != NULL) {
 		ZSTD_freeDStream(zstd_state.dctx);
@@ -723,6 +825,8 @@ int copyimage(void *out, struct img_type *img, writeimage callback)
 		.hash = img->sha256,
 		.encrypted = img->is_encrypted,
 		.imgivt = img->ivt_ascii,
+		.imgaes = img->aes_ascii,
+		.cipher = img->cipher,
 	};
 	return copyfile(&copy);
 }
