@@ -572,17 +572,20 @@ void *network_thread (void *data)
 
 				break;
 			case SET_AES_KEY:
-#ifndef CONFIG_PKCS11
-				msg.type = ACK;
-				if (set_aes_key(msg.data.aeskeymsg.key_ascii, msg.data.aeskeymsg.ivt_ascii))
-#endif
+				if (IS_STR_EQUAL(msg.data.aeskeymsg.key_ascii, "pkcs11"))
 					msg.type = NACK;
+				else {
+					msg.type = ACK;
+					if (set_aes_key(msg.data.aeskeymsg.key_ascii, msg.data.aeskeymsg.ivt_ascii))
+						msg.type = NACK;
+				}
 				break;
 			case SET_VERSIONS_RANGE:
 				msg.type = ACK;
-				set_version_range(msg.data.versions.minimum_version,
+				if (set_version_range(msg.data.versions.update_type,
+						  msg.data.versions.minimum_version,
 						  msg.data.versions.maximum_version,
-						  msg.data.versions.current_version);
+						  msg.data.versions.current_version)) msg.type = NACK;
 				break;
 			case GET_HW_REVISION:
 				cfg = get_swupdate_cfg();
