@@ -45,6 +45,7 @@
 #include "state.h"
 #include "bootloader.h"
 #include "hw-compatibility.h"
+#include "swupdate_crypto.h"
 
 #define BUFF_SIZE	 4096
 #define PERCENT_LB_INDEX	4
@@ -58,6 +59,16 @@ enum {
 
 static pthread_t network_thread_id;
 
+static bool check_reboot_enabled(struct swupdate_cfg *sw) {
+	if (sw->reboot_enabled != REBOOT_UNSET)
+		return sw->reboot_enabled == REBOOT_ENABLED;
+	struct swupdate_type_cfg *typecfg = sw->update_type;
+	if (typecfg->reboot_enabled != REBOOT_UNSET)
+		return typecfg->reboot_enabled == REBOOT_ENABLED;
+
+	return true;
+}
+
 /*
  * NOTE: these sync vars are _not_ static, they are _shared_ between the
  * installer, the display thread and the network thread
@@ -78,28 +89,37 @@ static int extract_file_to_tmp(int fd, const char *fname, unsigned long *poffs,
 {
 	char output_file[MAX_IMAGE_FNAME];
 	struct filehdr fdh;
-	int fdout;
+	int fdout = -1;
 	uint32_t checksum;
 	const char* TMPDIR = get_tmpdir();
+	cipher_t cipher = AES_CBC;
+	int ret = -1;
+
+#ifdef CONFIG_ASYM_ENCRYPTED_SW_DESCRIPTION
+	const char *cryptolib = get_cryptolib();
+	cipher = CMS;
+	if (encrypted)
+		set_cryptolib("opensslCMS");
+#endif
 
 	if (extract_cpio_header(fd, &fdh, poffs)) {
-		return -1;
+		goto err;
 	}
 	if (strcmp(fdh.filename, fname)) {
 		TRACE("description file name not the first of the list: %s instead of %s",
 			fdh.filename,
 			fname);
-		return -1;
+		goto err;
 	}
 	if (snprintf(output_file, sizeof(output_file), "%s%s", TMPDIR,
 		     fdh.filename) >= (int)sizeof(output_file)) {
 		ERROR("Path too long: %s%s", TMPDIR, fdh.filename);
-		return -1;
+		goto err;
 	}
 	if (max_size && fdh.size >= max_size) {
 		ERROR("%s size (%ld) exceeds configured max of %d, aborting",
 			fdh.filename, fdh.size, max_size);
-		return -1;
+		goto err;
 	}
 	TRACE("Found file");
 	TRACE("\tfilename %s", fdh.filename);
@@ -107,7 +127,7 @@ static int extract_file_to_tmp(int fd, const char *fname, unsigned long *poffs,
 
 	fdout = openfileoutput(output_file);
 	if (fdout < 0)
-		return -1;
+		goto err;
 
 	struct swupdate_copy copy = {
 		.fdin = fd,
@@ -116,18 +136,23 @@ static int extract_file_to_tmp(int fd, const char *fname, unsigned long *poffs,
 		.offs = poffs,
 		.checksum = &checksum,
 		.encrypted = encrypted,
+		.cipher = cipher,
 	};
 	if (copyfile(&copy) < 0) {
-		close(fdout);
-		return -1;
+		goto err;
 	}
 	if (!swupdate_verify_chksum(checksum, &fdh)) {
-		close(fdout);
-		return -1;
+		goto err;
 	}
-	close(fdout);
-
-	return 0;
+	ret = 0;
+err:
+#ifdef CONFIG_ASYM_ENCRYPTED_SW_DESCRIPTION
+	if (encrypted)
+		set_cryptolib(cryptolib);
+#endif
+	if (fdout >= 0)
+		close(fdout);
+	return ret;
 }
 
 static bool update_transaction_state(struct swupdate_cfg *software, update_state_t newstate)
@@ -319,6 +344,9 @@ static int extract_files(int fd, struct swupdate_cfg *software)
 					ERROR("Error streaming %s", img->fname);
 					return -1;
 				}
+
+				update_installed_image_version(&software->installed_sw_list, img);
+
 				TRACE("END INSTALLING STREAMING");
 				break;
 			}
@@ -562,6 +590,7 @@ void *network_initializer(void *data)
 	struct swupdate_cfg *software = data;
 	struct swupdate_request *req;
 	struct swupdate_parms parms;
+	bool do_reboot = true;
 
 	/* No installation in progress */
 	memset(&inst, 0, sizeof(inst));
@@ -711,10 +740,15 @@ void *network_initializer(void *data)
 			 * if this update is signalled to be without reboot (On the Fly),
 			 * send a notification via progress for processes responsible for booting
 			 */
-			if (!software->reboot_required) {
+			do_reboot = check_reboot_enabled(software);
+			if (!do_reboot) {
 				swupdate_progress_info(RUN, CAUSE_REBOOT_MODE , "{ \"reboot-mode\" : \"no-reboot\"}");
 			}
 
+			if (software->parms.dry_run) {
+				swupdate_progress_info(RUN, CAUSE_DRY_RUN_MODE , "{ \"dry-run\" : true }");
+			}
+
 			ret = install_images(software);
 			if (ret != 0) {
 				update_transaction_state(software, STATE_FAILED);
@@ -778,7 +812,7 @@ void *network_initializer(void *data)
 		 */
 		if (req->source == SOURCE_SURICATTA &&
 		    /*simple check without JSON */ strstr(req->info, "hawkbit") &&
-		    !software->reboot_required) {
+		    !do_reboot) {
 			ipc_message msg;
 			size_t size = sizeof(msg.data.procmsg.buf);
 			char *buf = msg.data.procmsg.buf;
@@ -855,22 +889,34 @@ sourcetype get_install_source(void)
 	return inst.req.source;
 }
 
-void set_version_range(const char *minversion,
+int set_version_range(const char *update_type, const char *minversion,
 		const char *maxversion, const char *current)
 {
+	struct swupdate_type_cfg *typecfg;
+	typecfg = swupdate_find_update_type(&inst.software->swupdate_types,
+					    update_type && strnlen(update_type, SWUPDATE_GENERAL_STRING_SIZE) ?
+					    update_type : "default");
+
+	if (!typecfg) {
+		ERROR("Configuration setup for Update Type not found");
+		return -EINVAL;
+	}
+
 	if (minversion && strnlen(minversion, SWUPDATE_GENERAL_STRING_SIZE)) {
-		strlcpy(inst.software->minimum_version, minversion,
-			sizeof(inst.software->minimum_version));
-		inst.software->no_downgrading = true;
+		strlcpy(typecfg->minimum_version, minversion,
+			sizeof(typecfg->minimum_version));
+		typecfg->no_downgrading = true;
 	}
 	if (maxversion && strnlen(maxversion, SWUPDATE_GENERAL_STRING_SIZE)) {
-		strlcpy(inst.software->maximum_version, maxversion,
-			sizeof(inst.software->maximum_version));
-		inst.software->check_max_version = true;
+		strlcpy(typecfg->maximum_version, maxversion,
+			sizeof(typecfg->maximum_version));
+		typecfg->check_max_version = true;
 	}
 	if (current && strnlen(current, SWUPDATE_GENERAL_STRING_SIZE)) {
-		strlcpy(inst.software->current_version, current,
-			sizeof(inst.software->current_version));
-		inst.software->no_reinstalling = true;
+		strlcpy(typecfg->current_version, current,
+			sizeof(typecfg->current_version));
+		typecfg->no_reinstalling = true;
 	}
+
+	return 0;
 }
