@@ -40,7 +40,6 @@
 #include "download_interface.h"
 #include "network_ipc.h"
 #include "network_utils.h"
-#include "sslapi.h"
 #include "suricatta/suricatta.h"
 #include "delta_process.h"
 #include "progress.h"
@@ -52,6 +51,7 @@
 #include "versions.h"
 #include "hw-compatibility.h"
 #include "swupdate_vars.h"
+#include "swupdate_crypto.h"
 
 #ifdef CONFIG_SYSTEMD
 #include <systemd/sd-daemon.h>
@@ -101,9 +101,19 @@ static struct option long_options[] = {
 #if defined(CONFIG_SIGALG_CMS) && !defined(CONFIG_SSL_IMPL_WOLFSSL)
 	{"forced-signer-name", required_argument, NULL, '2'},
 #endif
+#ifdef CONFIG_SIGALG_GPG
+	{"gpg-home-dir", required_argument, NULL, '4'},
+	{"gpg-protocol", required_argument, NULL, '5'},
+#endif
+	{"digest-provider", required_argument, NULL, '6'},
 #endif
 #ifdef CONFIG_ENCRYPTED_IMAGES
 	{"key-aes", required_argument, NULL, 'K'},
+	{"decryption-key", required_argument, NULL, 'K'},
+	{"decrypt-provider", required_argument, NULL, '8'},
+#endif
+#ifdef CONFIG_HASH_VERIFY
+	{"hash-provider", required_argument, NULL, '7'},
 #endif
 	{"loglevel", required_argument, NULL, 'l'},
 	{"max-version", required_argument, NULL, '3'},
@@ -155,7 +165,7 @@ static void usage(char *programname)
 		" -l, --loglevel <level>         : logging level\n"
 		" -L, --syslog                   : enable syslog logger\n"
 #ifdef CONFIG_SIGNED_IMAGES
-#ifndef CONFIG_SIGALG_GPG
+		" --digest-provider <string>     : the provider used to verify the update\n"
 		" -k, --key <public key file>    : file with public key to verify images\n"
 		"     --cert-purpose <purpose>   : set expected certificate purpose\n"
 		"                                  [emailProtection|codeSigning] (default: emailProtection)\n"
@@ -163,11 +173,19 @@ static void usage(char *programname)
 		"     --forced-signer-name <cn>  : set expected common name of signer certificate\n"
 #endif
 		"     --ca-path                  : path to the Certificate Authority (PEM)\n"
+#ifdef CONFIG_SIGALG_GPG
+		" For GnuPG only:\n"
+		"     --gpg-home-dir             : path where the GPG ring and keys are stored\n"
+		"     --gpg-protocol             : supported protocol, openpgp or cms\n"
 #endif
 #endif
 #ifdef CONFIG_ENCRYPTED_IMAGES
-		" -K, --key-aes <key file>       : the file contains the symmetric key to be used\n"
-		"                                  to decrypt images\n"
+		" -K, --key-aes <key file>       : the file contains the decryption key to be used\n"
+		"     --decryption-key <key file>: to decrypt images\n"
+		" --decrypt-provider <string>    : the provider used for decryption\n"
+#endif
+#ifdef CONFIG_HASH_VERIFY
+		" --hash-provider <string>       : the provider used to perform hashes\n"
 #endif
 		" -n, --dry-run                  : run SWUpdate without installing the software\n"
 		" -N, --no-downgrading <version> : not install a release older as <version>\n"
@@ -265,6 +283,12 @@ static int parse_image_selector(const char *selector, struct swupdate_cfg *sw)
 
 static void swupdate_init(struct swupdate_cfg *sw)
 {
+	struct swupdate_type_cfg *update_type = calloc (1, sizeof(*update_type));
+	if (!update_type) {
+		/* this should never happen */
+		fprintf(stderr, "OOM at startup, exiting...\n");
+		exit(EXIT_FAILURE);
+	}
 	/* Initialize internal tree to store configuration */
 	memset(sw, 0, sizeof(*sw));
 	LIST_INIT(&sw->images);
@@ -272,7 +296,12 @@ static void swupdate_init(struct swupdate_cfg *sw)
 	LIST_INIT(&sw->scripts);
 	LIST_INIT(&sw->bootloader);
 	LIST_INIT(&sw->extprocs);
-	sw->cert_purpose = SSL_PURPOSE_DEFAULT;
+	LIST_INIT(&sw->swupdate_types);
+	strlcpy(update_type->type_name, "default", sizeof(update_type->type_name));
+	LIST_INSERT_HEAD(&sw->swupdate_types, update_type, next);
+	sw->update_type = update_type;
+
+	sw->cert_purpose = CERT_PURPOSE_EMAIL_PROT;
 
 #ifdef CONFIG_MTD
 	mtd_init();
@@ -286,15 +315,55 @@ static int parse_cert_purpose(const char *text)
 	static const char EMAIL_PROT[] = "emailProtection";
 
 	if (strncmp(CODE_SIGN, text, sizeof(CODE_SIGN)) == 0)
-		return SSL_PURPOSE_CODE_SIGN;
+		return CERT_PURPOSE_CODE_SIGN;
 
 	if (strncmp(EMAIL_PROT, text, sizeof(EMAIL_PROT)) == 0)
-		return SSL_PURPOSE_EMAIL_PROT;
+		return CERT_PURPOSE_EMAIL_PROT;
 
 	ERROR("unknown certificate purpose '%s'\n", text);
 	exit(EXIT_FAILURE);
 }
 
+static void read_updatetype_settings(void *elem, struct swupdate_type_cfg *typecfg)
+{
+	char tmp[SWUPDATE_GENERAL_STRING_SIZE] = "";
+
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"postupdatecmd", typecfg->postupdatecmd);
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"preupdatecmd", typecfg->preupdatecmd);
+
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"no-downgrading", typecfg->minimum_version);
+
+	if (strlen(typecfg->minimum_version))
+		typecfg->no_downgrading = true;
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"max-version", typecfg->maximum_version);
+	if (strlen(typecfg->maximum_version))
+		typecfg->check_max_version = true;
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"no-reinstalling", typecfg->current_version);
+	if (strlen(typecfg->current_version))
+		typecfg->no_reinstalling = true;
+
+	/*
+	 * As default, reboot is initiated
+	 */
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"reboot", tmp);
+	typecfg->reboot_enabled = REBOOT_UNSET;
+	if (tmp[0] != '\0') {
+		if (!is_enabled_or_disabled(tmp)) {
+			WARN("Possible mismatch for reboot attribute, it is neither enabled nor disabled");
+		} else if (is_enabled(tmp)) {
+			typecfg->reboot_enabled = REBOOT_ENABLED;
+		} else {
+			typecfg->reboot_enabled = REBOOT_DISABLED;
+		}
+	}
+}
+
 static int read_globals_settings(void *elem, void *data)
 {
 	char tmp[SWUPDATE_GENERAL_STRING_SIZE] = "";
@@ -315,12 +384,10 @@ static int read_globals_settings(void *elem, void *data)
 				"ca-path", sw->publickeyfname);
 	GET_FIELD_STRING(LIBCFG_PARSER, elem,
 				"aes-key-file", sw->aeskeyfname);
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"decryption-key-file", sw->aeskeyfname);
 	GET_FIELD_STRING(LIBCFG_PARSER, elem,
 				"mtd-blacklist", sw->mtdblacklist);
-	GET_FIELD_STRING(LIBCFG_PARSER, elem,
-				"postupdatecmd", sw->postupdatecmd);
-	GET_FIELD_STRING(LIBCFG_PARSER, elem,
-				"preupdatecmd", sw->preupdatecmd);
 	GET_FIELD_STRING(LIBCFG_PARSER, elem,
 				"namespace-vars", sw->namespace_for_vars);
 	GET_FIELD_STRING(LIBCFG_PARSER, elem,
@@ -333,8 +400,7 @@ static int read_globals_settings(void *elem, void *data)
 	GET_FIELD_BOOL(LIBCFG_PARSER, elem, "verbose", &sw->verbose);
 	GET_FIELD_INT(LIBCFG_PARSER, elem, "loglevel", &sw->loglevel);
 	GET_FIELD_BOOL(LIBCFG_PARSER, elem, "syslog", &sw->syslog_enabled);
-	GET_FIELD_STRING(LIBCFG_PARSER, elem,
-				"no-downgrading", sw->minimum_version);
+	GET_FIELD_BOOL(LIBCFG_PARSER, elem, "update-type-required", &sw->update_type_required);
 	tmp[0] = '\0';
 	GET_FIELD_STRING(LIBCFG_PARSER, elem,
 				"fwenv-config-location", tmp);
@@ -342,16 +408,6 @@ static int read_globals_settings(void *elem, void *data)
 		set_fwenv_config(tmp);
 		tmp[0] = '\0';
 	}
-	if (strlen(sw->minimum_version))
-		sw->no_downgrading = true;
-	GET_FIELD_STRING(LIBCFG_PARSER, elem,
-				"max-version", sw->maximum_version);
-	if (strlen(sw->maximum_version))
-		sw->check_max_version = true;
-	GET_FIELD_STRING(LIBCFG_PARSER, elem,
-				"no-reinstalling", sw->current_version);
-	if (strlen(sw->current_version))
-		sw->no_reinstalling = true;
 	GET_FIELD_STRING(LIBCFG_PARSER, elem,
 				"cert-purpose", tmp);
 	if (tmp[0] != '\0')
@@ -361,6 +417,16 @@ static int read_globals_settings(void *elem, void *data)
 
 	char software_select[SWUPDATE_GENERAL_STRING_SIZE] = "";
 	GET_FIELD_STRING(LIBCFG_PARSER, elem, "select", software_select);
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"gpg-home-dir", sw->gpg_home_directory);
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"gpgme-protocol", sw->gpgme_protocol);
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"hash-provider", sw->hash_provider);
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"decrypt-provider", sw->decrypt_provider);
+	GET_FIELD_STRING(LIBCFG_PARSER, elem,
+				"digest-provider", sw->digest_provider);
 	if (software_select[0] != '\0') {
 		/* by convention, errors in a configuration section are ignored */
 		(void)parse_image_selector(software_select, sw);
@@ -372,6 +438,9 @@ static int read_globals_settings(void *elem, void *data)
 	GET_FIELD_INT(LIBCFG_PARSER, elem, "sw-description-max-size",
 				&sw->swdesc_max_size);
 
+
+	read_updatetype_settings(elem, sw->update_type);
+
 	return 0;
 }
 
@@ -440,6 +509,61 @@ static int read_processes_settings(void *settings, void *data)
 	return 0;
 }
 
+static int read_type_settings(void *settings, void *data)
+{
+	struct swupdate_cfg *sw = (struct swupdate_cfg *)data;
+	void *elem;
+	int count, i;
+	count = get_array_length(LIBCFG_PARSER, settings);
+	struct swupdate_type_cfg *current = LIST_FIRST(&sw->swupdate_types);
+
+	for(i = 0; i < count; ++i) {
+		elem = get_elem_from_idx(LIBCFG_PARSER, settings, i);
+
+		if (!elem)
+			continue;
+
+		if(!(exist_field_string(LIBCFG_PARSER, elem, "name")))
+			continue;
+		struct swupdate_type_cfg *update_type = calloc (1, sizeof(*update_type));
+		if (!update_type) {
+			ERROR("OOM at startup");
+			return -ENOMEM;
+		}
+
+		GET_FIELD_STRING(LIBCFG_PARSER, elem, "name", update_type->type_name);
+		if (swupdate_find_update_type(&sw->swupdate_types, update_type->type_name)) {
+			WARN("Duplicated Update Type: %s, ignoring...", update_type->type_name);
+			free(update_type);
+			continue;
+		}
+		read_updatetype_settings(elem, update_type);
+		LIST_INSERT_AFTER(current, update_type, next);
+		current = update_type;
+	}
+
+	return 0;
+}
+
+static void print_registered_updatetypes(struct swupdate_cfg *sw)
+{
+	struct swupdate_type_cfg *update_type;
+	INFO("Registered : Update Types");
+	LIST_FOREACH(update_type, &sw->swupdate_types, next) {
+		INFO("\tName:\t%s", update_type->type_name);
+		if (strlen(update_type->preupdatecmd))
+			INFO("\t\tpreupdatecmd:\t%s", update_type->preupdatecmd);
+		if (strlen(update_type->postupdatecmd))
+			INFO("\t\tpostupdatecmd:\t%s", update_type->postupdatecmd);
+		if (strlen(update_type->minimum_version))
+			INFO("\t\tMin Version:\t%s", update_type->minimum_version);
+		if (strlen(update_type->maximum_version))
+			INFO("\t\tMax Version:\t%s", update_type->maximum_version);
+		if (strlen(update_type->current_version))
+			INFO("\t\tNo-Downgrading:\t%s", update_type->current_version);
+	}
+}
+
 static void sigterm_handler(int __attribute__ ((__unused__)) signum)
 {
 	pthread_cancel(network_daemon);
@@ -499,8 +623,8 @@ int main(int argc, char **argv)
 	strcat(main_options, "H:");
 #endif
 #ifdef CONFIG_SIGNED_IMAGES
-#ifndef CONFIG_SIGALG_GPG
 	strcat(main_options, "k:");
+#ifndef CONFIG_SIGALG_GPG
 	public_key_mandatory = 1;
 #endif
 #endif
@@ -531,7 +655,7 @@ int main(int argc, char **argv)
 		char *root;
 		int bootdev;
 		case 'f':
-			cfgfname = strdup(optarg);
+			if (optarg) cfgfname = strdup(optarg);
 			break;
 		case 'g':
 			root = get_root_device();
@@ -554,7 +678,7 @@ int main(int argc, char **argv)
 			exit(EXIT_SUCCESS);
 			break;
 		case 'l':
-			loglevel = strtoul(optarg, NULL, 10);
+			if (optarg) loglevel = strtoul(optarg, NULL, 10);
 			break;
 		case 'v':
 			loglevel = LASTLOGLEVEL;
@@ -599,6 +723,14 @@ int main(int argc, char **argv)
 			exit(EXIT_FAILURE);
 		}
 
+		/*
+		 * Read configuration for different update types
+		 */
+		ret = read_module_settings(&handle, "update-types", read_type_settings, &swcfg);
+		if (ret && swcfg.update_type_required) {
+			WARN("Type is requested, but no type is configured, just default");
+		}
+
 		loglevel = swcfg.verbose ? LASTLOGLEVEL : swcfg.loglevel;
 
 		/*
@@ -634,18 +766,20 @@ int main(int argc, char **argv)
 			break;
 #ifdef CONFIG_UBIATTACH
 		case 'b':
-			mtd_set_ubiblacklist(optarg);
+			if (optarg) mtd_set_ubiblacklist(optarg);
 			break;
 #endif
 		case 'i':
-			strlcpy(fname, optarg, sizeof(fname));
-			opt_i = 1;
+			if (optarg) {
+				strlcpy(fname, optarg, sizeof(fname));
+				opt_i = 1;
+			}
 			break;
 		case 'o':
-			strlcpy(swcfg.output, optarg, sizeof(swcfg.output));
+			if (optarg) strlcpy(swcfg.output, optarg, sizeof(swcfg.output));
 			break;
 		case 's':
-			strlcpy(swcfg.output_swversions, optarg, sizeof(swcfg.output_swversions));
+			if (optarg) strlcpy(swcfg.output_swversions, optarg, sizeof(swcfg.output_swversions));
 			break;
 		case 'B':
 			if (set_bootloader(optarg) != 0) {
@@ -655,7 +789,7 @@ int main(int argc, char **argv)
 			}
 			break;
 		case 'l':
-			loglevel = strtoul(optarg, NULL, 10);
+			if (optarg) loglevel = strtoul(optarg, NULL, 10);
 			break;
 		case 'n':
 			swcfg.parms.dry_run = true;
@@ -664,38 +798,67 @@ int main(int argc, char **argv)
 			swcfg.syslog_enabled = true;
 			break;
 		case 'k':
-			strlcpy(swcfg.publickeyfname,
+			if (optarg) strlcpy(swcfg.publickeyfname,
 				optarg,
 			       	sizeof(swcfg.publickeyfname));
 			break;
 		case '1':
-			swcfg.cert_purpose = parse_cert_purpose(optarg);
+			if (optarg) swcfg.cert_purpose = parse_cert_purpose(optarg);
 			break;
 		case '2':
-			strlcpy(swcfg.forced_signer_name, optarg,
+			if (optarg) strlcpy(swcfg.forced_signer_name, optarg,
 				sizeof(swcfg.forced_signer_name));
 			break;
 		case '3':
-			swcfg.check_max_version = true;
-			strlcpy(swcfg.maximum_version, optarg,
-				sizeof(swcfg.maximum_version));
+			if (optarg) {
+				swcfg.update_type->check_max_version = true;
+				strlcpy(swcfg.update_type->maximum_version, optarg,
+					sizeof(swcfg.update_type->maximum_version));
+			}
+			break;
+		case '4':
+			strlcpy(swcfg.gpg_home_directory,
+				optarg,
+				sizeof(swcfg.gpg_home_directory));
+			break;
+		case '5':
+			strlcpy(swcfg.gpgme_protocol,
+				optarg,
+				sizeof(swcfg.gpgme_protocol));
+			break;
+		case '6':
+			strlcpy(swcfg.digest_provider,
+				optarg,
+				sizeof(swcfg.digest_provider));
+			break;
+		case '7':
+			strlcpy(swcfg.hash_provider,
+				optarg,
+				sizeof(swcfg.hash_provider));
+			break;
+		case '8':
+			strlcpy(swcfg.decrypt_provider,
+				optarg,
+				sizeof(swcfg.decrypt_provider));
 			break;
 #ifdef CONFIG_ENCRYPTED_IMAGES
 		case 'K':
-			strlcpy(swcfg.aeskeyfname,
-				optarg,
-			       	sizeof(swcfg.aeskeyfname));
+			if (optarg) strlcpy(swcfg.aeskeyfname,
+					    optarg,
+					    sizeof(swcfg.aeskeyfname));
 			break;
 #endif
 		case 'N':
-			swcfg.no_downgrading = true;
-			strlcpy(swcfg.minimum_version, optarg,
-				sizeof(swcfg.minimum_version));
+			swcfg.update_type->no_downgrading = true;
+			if (optarg) strlcpy(swcfg.update_type->minimum_version, optarg,
+					    sizeof(swcfg.update_type->minimum_version));
 			break;
 		case 'R':
-			swcfg.no_reinstalling = true;
-			strlcpy(swcfg.current_version, optarg,
-				sizeof(swcfg.current_version));
+			if (optarg) {
+				swcfg.update_type->no_reinstalling = true;
+				strlcpy(swcfg.update_type->current_version, optarg,
+					sizeof(swcfg.update_type->current_version));
+			}
 			break;
 		case 'M':
 			swcfg.no_transaction_marker = true;
@@ -706,8 +869,10 @@ int main(int argc, char **argv)
 			TRACE("state_marker globally disabled");
 			break;
 		case 'e':
-			software_select = optarg;
-			opt_e = 1;
+			if (optarg) {
+				software_select = optarg;
+				opt_e = 1;
+			}
 			break;
 		/* Configuration file already parsed, ignores it */
 		case 'f':
@@ -733,7 +898,7 @@ int main(int argc, char **argv)
 				exit(EXIT_FAILURE);
 			break;
 		case 'q':
-			dict_insert_value(&swcfg.accepted_set, "accepted", optarg);
+			if (optarg) dict_insert_value(&swcfg.accepted_set, "accepted", optarg);
 			break;
 #ifdef CONFIG_SURICATTA
 		case 'u':
@@ -763,12 +928,12 @@ int main(int argc, char **argv)
 			opt_c = true;
 			break;
 		case 'p':
-			strlcpy(swcfg.postupdatecmd, optarg,
-				sizeof(swcfg.postupdatecmd));
+			if (optarg) strlcpy(swcfg.update_type->postupdatecmd, optarg,
+					    sizeof(swcfg.update_type->postupdatecmd));
 			break;
 		case 'P':
-			strlcpy(swcfg.preupdatecmd, optarg,
-				sizeof(swcfg.preupdatecmd));
+			if (optarg )strlcpy(swcfg.update_type->preupdatecmd, optarg,
+					    sizeof(swcfg.update_type->preupdatecmd));
 			break;
 		default:
 			fprintf(stdout, "Try %s -h for usage\n", argv[0]);
@@ -828,10 +993,23 @@ int main(int argc, char **argv)
 
 	swupdate_crypto_init();
 
-	if (strlen(swcfg.publickeyfname) || strlen(swcfg.gpg_home_directory)) {
-		if (swupdate_dgst_init(&swcfg, swcfg.publickeyfname)) {
-			fprintf(stderr,
-				 "Error: Crypto cannot be initialized.\n");
+	if (strlen(swcfg.hash_provider)) {
+		if (set_HASHlib(swcfg.hash_provider)) {
+			ERROR("HASH provider %s cannot be set", swcfg.hash_provider);
+			exit(EXIT_FAILURE);
+		}
+	}
+
+	if (strlen(swcfg.decrypt_provider)) {
+		if (set_cryptolib(swcfg.decrypt_provider)) {
+			ERROR("Decrypt provider %s cannot be set", swcfg.decrypt_provider);
+			exit(EXIT_FAILURE);
+		}
+	}
+
+	if (strlen(swcfg.digest_provider)) {
+		if (set_dgstlib(swcfg.digest_provider)) {
+			ERROR("Verification provider %s cannot be set", swcfg.digest_provider);
 			exit(EXIT_FAILURE);
 		}
 	}
@@ -854,6 +1032,18 @@ int main(int argc, char **argv)
 		INFO("Using bootloader interface: %s", get_bootloader());
 	}
 
+	print_registered_updatetypes(&swcfg);
+	print_registered_cryptolib();
+
+#ifdef CONFIG_SIGNED_IMAGES
+	if (strlen(swcfg.publickeyfname) || strlen(swcfg.gpg_home_directory)) {
+		if (swupdate_dgst_init(&swcfg, swcfg.publickeyfname)) {
+			ERROR("Error: Crypto cannot be initialized.\n");
+			exit(EXIT_FAILURE);
+		}
+	}
+#endif
+
 	/*
 	 * Install a child handler to check if a subprocess
 	 * dies
