@@ -37,23 +37,6 @@
 #include "util.h"
 #include "generated/autoconf.h"
 
-/*
- * key    is 256 bit for max aes_256
- * keylen is the actual aes key length
- * ivt    is 128 bit
- */
-struct decryption_key {
-#ifdef CONFIG_PKCS11
-	char * key;
-#else
-	unsigned char key[AES_256_KEY_LEN];
-#endif
-	char keylen;
-	unsigned char ivt[AES_BLK_SIZE];
-};
-
-static struct decryption_key *aes_key = NULL;
-
 /*
  * Configuration file for fw_env.config
  */
@@ -509,63 +492,6 @@ int count_elem_list(struct imglist *list)
 	return count;
 }
 
-int load_decryption_key(char *fname)
-{
-	FILE *fp;
-	char *b1 = NULL, *b2 = NULL;
-	int ret;
-
-	fp = fopen(fname, "r");
-	if (!fp)
-		return -EBADF;
-
-	ret = fscanf(fp, "%ms %ms", &b1, &b2);
-	switch (ret) {
-		case 2:
-			DEBUG("Read decryption key and initialization vector from file %s.", fname);
-			break;
-		default:
-			if (b1 != NULL)
-				free(b1);
-			fprintf(stderr, "File with decryption key is not in the format <key> <ivt>\n");
-			fclose(fp);
-			return -EINVAL;
-	}
-	fclose(fp);
-
-	ret = set_aes_key(b1, b2);
-
-	if (b1 != NULL)
-		free(b1);
-	if (b2 != NULL)
-		free(b2);
-
-	if (ret) {
-		fprintf(stderr, "Keys are invalid\n");
-		return -EINVAL;
-	}
-
-	return 0;
-}
-
-unsigned char *get_aes_key(void) {
-	if (!aes_key)
-		return NULL;
-	return aes_key->key;
-}
-
-char get_aes_keylen(void) {
-	if (!aes_key)
-		return -1;
-	return aes_key->keylen;
-}
-
-unsigned char *get_aes_ivt(void) {
-	if (!aes_key)
-		return NULL;
-	return aes_key->ivt;
-}
-
 bool is_hex_str(const char *ascii) {
 	unsigned int i, size;
 
@@ -583,57 +509,6 @@ bool is_hex_str(const char *ascii) {
 	return true;
 }
 
-int set_aes_key(const char *key, const char *ivt)
-{
-	int ret;
-	size_t keylen;
-
-	/*
-	 * Allocates the global structure just once
-	 */
-	if (!aes_key) {
-		aes_key = (struct decryption_key *)calloc(1, sizeof(*aes_key));
-		if (!aes_key)
-			return -ENOMEM;
-	}
-
-	if (strlen(ivt) != (AES_BLK_SIZE*2) || !is_hex_str(ivt)) {
-		ERROR("Invalid ivt");
-		return -EINVAL;
-	}
-
-	ret = ascii_to_bin(aes_key->ivt, sizeof(aes_key->ivt), ivt);
-#ifdef CONFIG_PKCS11
-	keylen = strlen(key) + 1;
-	aes_key->key = malloc(keylen);
-	if (!aes_key->key)
-		return -ENOMEM;
-	strncpy(aes_key->key, key, keylen);
-#else
-	keylen = strlen(key);
-	switch (keylen) {
-	case AES_128_KEY_LEN * 2:
-	case AES_192_KEY_LEN * 2:
-	case AES_256_KEY_LEN * 2:
-		// valid hex string size for AES 128/192/256
-		aes_key->keylen = keylen / 2;
-		break;
-	default:
-		ERROR("Invalid aes_key length");
-		return -EINVAL;
-	}
-	ret |= !is_hex_str(key);
-	ret |= ascii_to_bin(aes_key->key, aes_key->keylen, key);
-#endif
-
-	if (ret) {
-		ERROR("Invalid aes_key");
-		return -EINVAL;
-	}
-
-	return 0;
-}
-
 const char *get_fwenv_config(void) {
 	if (!fwenv_config)
 #if defined(CONFIG_UBOOT)
@@ -1164,11 +1039,10 @@ static char *get_root_from_mountinfo(void)
 }
 
 #define MAX_CMDLINE_LENGTH 4096
-static char *get_root_from_cmdline(void)
+char **parse_linux_cmdline(void)
 {
 	char *buf;
 	FILE *fp;
-	char *root = NULL;
 	int ret;
 	char **parms = NULL;
 
@@ -1192,10 +1066,25 @@ static char *get_root_from_cmdline(void)
 	 */
 	buf[MAX_CMDLINE_LENGTH - 1] = '\0';
 
+	fclose(fp);
+
 	if (ret > 0) {
 		parms = string_split(buf, ' ');
 		if (!parms)
 			goto out;
+	}
+out:
+	free(buf);
+	return parms;
+}
+
+static char *get_root_from_cmdline(void)
+{
+	char **parms = NULL;
+	char *root = NULL;
+
+	parms = parse_linux_cmdline();
+	if (parms) {
 		int nparms = count_string_array((const char **)parms);
 		for (unsigned int index = 0; index < nparms; index++) {
 			if (!strncmp(parms[index], "root=", strlen("root="))) {
@@ -1207,11 +1096,8 @@ static char *get_root_from_cmdline(void)
 				break;
 			}
 		}
+		free_string_array(parms);
 	}
-out:
-	fclose(fp);
-	free_string_array(parms);
-	free(buf);
 	return root;
 }
 
