@@ -23,7 +23,7 @@
 #include <network_ipc.h>
 #include <util.h>
 #include "channel_op_res.h"
-#include "sslapi.h"
+#include "swupdate_crypto.h"
 #include "channel.h"
 #include "channel_curl.h"
 #include "progress.h"
