@@ -283,6 +283,8 @@ static void lua_string_to_img(struct img_type *img, const char *key,
 	if (!strcmp(key, "compressed")) {
 		if (!strcmp(value, "zlib")) {
 			img->compressed = COMPRESSED_ZLIB;
+		} else if (!strcmp(value, "xz")) {
+			img->compressed = COMPRESSED_XZ;
 		} else if (!strcmp(value, "zstd")) {
 			img->compressed = COMPRESSED_ZSTD;
 		} else {
@@ -328,7 +330,9 @@ static void lua_string_to_img(struct img_type *img, const char *key,
 	if (!strcmp(key, "ivt"))
 		strncpy(img->ivt_ascii, value,
 			sizeof(img->ivt_ascii));
-
+	if (!strcmp(key, "aes-key"))
+		strncpy(img->aes_ascii, value,
+			sizeof(img->aes_ascii));
 	if (!strncmp(key, offset, sizeof(offset))) {
 		strncpy(seek_str, value,
 			sizeof(seek_str));
@@ -512,6 +516,7 @@ static void update_table(lua_State* L, struct img_type *img)
 		LUA_PUSH_IMG_STRING(img, "data", type_data);
 		LUA_PUSH_IMG_STRING(img, "filesystem", filesystem);
 		LUA_PUSH_IMG_STRING(img, "ivt", ivt_ascii);
+		LUA_PUSH_IMG_STRING(img, "aes-key", aes_ascii);
 
 		LUA_PUSH_IMG_BOOL(img, "installed_directly", install_directly);
 		LUA_PUSH_IMG_BOOL(img, "install_if_different", id.install_if_different);
@@ -530,6 +535,9 @@ static void update_table(lua_State* L, struct img_type *img)
 			case COMPRESSED_ZLIB:
 				LUA_PUSH_IMG_STRING_VALUE(img, "compressed", "zlib");
 				break;
+			case COMPRESSED_XZ:
+				LUA_PUSH_IMG_STRING_VALUE(img, "compressed", "xz");
+				break;
 			case COMPRESSED_ZSTD:
 				LUA_PUSH_IMG_STRING_VALUE(img, "compressed", "zstd");
 				break;
@@ -888,6 +896,41 @@ static int l_getroot(lua_State *L) {
 	return 1;
 }
 
+static int l_get_cmdline(lua_State *L) {
+	char **parms = NULL;
+
+	parms = parse_linux_cmdline();
+	if (!parms) {
+		lua_pushnil(L);
+		return 1;
+	}
+	lua_newtable (L);
+
+	int nparms = count_string_array((const char **)parms);
+	TRACE("parms=%d", nparms);
+	for (unsigned int index = 0; index < nparms; index++) {
+		char *equal = strchr(parms[index], '=');
+		const char *val;
+		if (equal) {
+			val = equal + 1;
+			/* split into two strings */
+			*equal = '\0';
+		} else {
+			/*
+			 * A table cannot have a nil value
+			 * so just set an empty string
+			 */
+			val = ""; 
+		}
+		lua_pushstring(L, parms[index]);
+		lua_pushstring(L, val);
+		lua_settable(L, -3);
+	}
+
+	free_string_array(parms);
+	return 1;
+}
+
 static int l_get_bootenv(lua_State *L) {
 	const char *name = luaL_checkstring(L, 1);
 	char *value = NULL;
@@ -950,7 +993,8 @@ static int l_get_tmpdir_scripts(lua_State *L)
 
 static int l_progress_update(lua_State *L)
 {
-	lua_Number percent =  luaL_checknumber (L, 1);
+	lua_Number percent = luaL_checknumber(L, 1);
+	lua_pop(L, 1);
 	swupdate_progress_update((unsigned int) percent);
 	return 0;
 }
@@ -1009,6 +1053,7 @@ int lua_get_swupdate_version(lua_State *L)
 {
 	const unsigned int version = VERSION;
 	const unsigned int patchlevel = VERSION_PATCHLEVEL;
+	const unsigned int sublevel = VERSION_SUBLEVEL;
 
 	lua_newtable (L);
 	lua_pushnumber(L, 1);
@@ -1017,8 +1062,12 @@ int lua_get_swupdate_version(lua_State *L)
 	lua_pushnumber(L, 2);
 	lua_pushnumber(L, patchlevel);
 	lua_settable(L, -3);
+	lua_pushnumber(L, 3);
+	lua_pushnumber(L, sublevel);
+	lua_settable(L, -3);
 	lua_push_enum(L, "version", version);
 	lua_push_enum(L, "patchlevel", patchlevel);
+	lua_push_enum(L, "sublevel", sublevel);
 	return 1;
 }
 
@@ -1186,17 +1235,18 @@ static int l_stat(lua_State *L)
  * @brief Dispatch a message to the progress interface.
  *
  * @param [Lua] Message to dispatch to progress interface.
+ * @param [Lua] progress_cause_t number (optional), default: CAUSE_NONE
  * @return [Lua] nil.
  */
 int lua_notify_progress(lua_State *L) {
-  /*
-   * NOTE: level is INFOLEVEL for the sake of specifying a level.
-   * It is unused in core/notifier.c :: progress_notifier() as the
-   * progress emitter doesn't know about log levels.
-   */
-  notify(PROGRESS, RECOVERY_NO_ERROR, INFOLEVEL, luaL_checkstring(L, -1));
-  lua_pop(L, 1);
-  return 0;
+	lua_Number cause = CAUSE_NONE;
+	if (lua_isnumber(L, -1) == 1) {
+		cause = lua_tonumber(L, -1);
+		lua_pop(L, 1);
+	}
+	notify(PROGRESS, (progress_cause_t)cause, INFOLEVEL, luaL_checkstring(L, -1));
+	lua_pop(L, 1);
+	return 0;
 }
 
 /**
@@ -1225,6 +1275,7 @@ static const luaL_Reg l_swupdate_bootenv[] = {
         { "get_bootenv", l_get_bootenv },
         { "set_bootenv", l_set_bootenv },
         { "get_selection", l_get_selection },
+        { "get_cmdline", l_get_cmdline },
         { NULL, NULL }
 };
 
