@@ -44,6 +44,9 @@
 #include "progress.h"
 #include "handler.h"
 #include "util.h"
+#ifdef CONFIG_MTD
+#include "flash.h"
+#endif
 #include "handler_helpers.h"
 #include "installer.h"
 
@@ -235,7 +238,17 @@ static int copy_image_file(struct img_type *img, void *data)
 	script_data = data;
 
 	base_img = img;
-
+#ifdef CONFIG_MTD
+	if(strlen(img->mtdname) ){
+		int mtdnum = get_mtd_from_name(img->mtdname);
+		if (mtdnum < 0) {
+			ERROR("Wrong MTD name in description: %s",
+			      img->mtdname);
+			return -1;
+		}
+		snprintf(img->device, sizeof(img->device), "/dev/mtdblock%d", mtdnum);
+	}
+#endif
 	proplist = dict_get_list(&img->properties, "type");
 	if (proplist) {
 		entry = LIST_FIRST(proplist);
@@ -258,7 +271,19 @@ static int copy_image_file(struct img_type *img, void *data)
 		ERROR("Missing source device, no copyfrom property");
 		return -EINVAL;
 	}
-
+#ifdef CONFIG_MTD
+	if (!strncmp("mtd:", entry->value, 4)) {
+		int mtdnum = get_mtd_from_name(entry->value + 4);
+		if (mtdnum < 0) {
+			ERROR("Wrong MTD name in copyfrom: %s",
+			      entry->value);
+			return -1;
+		}
+		free(entry->value);
+		entry->value = malloc(20+1); /* to hold "/dev/mtdblockXX */
+		snprintf(entry->value, 20, "/dev/mtdblock%d", mtdnum);
+	}
+#endif
 	copyfrom = realpath(entry->value, NULL);
 	if (!copyfrom) {
 		ERROR("%s cannot be resolved", entry->value);
@@ -295,15 +320,24 @@ static int copy_image_file(struct img_type *img, void *data)
 	recursive = strtobool(dict_get_value(&img->properties, "recursive"));
 	createdest = strtobool(dict_get_value(&img->properties, "create-destination"));
 
-
 	if (createdest) {
-		ret = mkpath(recursive ? base_img->path : dirname(base_img->path), 0755);
+		if (!strlen(base_img->path)) {
+			ERROR("Destination must be created, but no path set");
+			return -EINVAL;
+		}
+		char *tmppath = strdup(img->path);
+		if (!tmppath) {
+			ERROR("OOM creating local image path");
+			return -ENOMEM;
+		}
+		ret = mkpath(recursive ? tmppath : dirname(tmppath), 0755);
 		if (ret < 0) {
-			ERROR("I cannot create path %s: %s",
-				recursive ? base_img->path : dirname(base_img->path),
+			ERROR("I cannot create path %s: %s", tmppath,
 				strerror(errno));
+			free(tmppath);
 			ret = -EFAULT;
 		}
+		free(tmppath);
 	}
 
 	if (!ret) {
