@@ -248,9 +248,30 @@ static int update_volume(libubi_t libubi, struct img_type *img,
 		ERROR("cannot open UBI volume \"%s\"", node);
 		return -1;
 	}
-	err = ubi_update_start(libubi, fdout, bytes);
+
+	unsigned int retries = 3;
+	do {
+		/*
+		 * libubi just returns -1, errno can be checked
+		 * for the source of errors.
+		 * This should be changed in case ubi_update_start()
+		 * will do own error recovery in future.
+		 * Simply retries in case of error if the volume
+		 * is accessed by another process
+		 */
+		err = ubi_update_start(libubi, fdout, bytes);
+		retries--;
+		if (err) {
+			if (errno != EBUSY)
+				break;
+			WARN("Not possible to lock UBI, retry");
+			sleep(1);
+		}
+	} while (err && retries > 0);
+
 	if (err) {
 		ERROR("cannot start volume \"%s\" update", node);
+		close(fdout);
 		return -1;
 	}
 
@@ -289,6 +310,7 @@ static int resize_volume(struct img_type *cfg, long long size)
 	struct ubi_mkvol_request req;
 	struct mtd_ubi_info *mtd_info;
 	int mtdnum, req_vol_type;
+	int req_vol_id = UBI_VOL_NUM_AUTO;
 	char node[64];
 	int err;
 	struct flash_description *flash = get_flash_info();
@@ -350,6 +372,7 @@ static int resize_volume(struct img_type *cfg, long long size)
 		}
 
 		snprintf(node, sizeof(node), "/dev/ubi%d", ubivol->vol_info.dev_num);
+		req_vol_id = ubivol->vol_info.vol_id;
 		err = ubi_rmvol(nandubi->libubi, node, ubivol->vol_info.vol_id);
 		if (err) {
 			ERROR("Volume %s cannot be dropped", ubivol->vol_info.name);
@@ -371,7 +394,7 @@ static int resize_volume(struct img_type *cfg, long long size)
 		 */
 		memset(&req, 0, sizeof(req));
 		req.vol_type = req_vol_type;
-		req.vol_id = UBI_VOL_NUM_AUTO;
+		req.vol_id = req_vol_id;
 		req.alignment = 1;
 		req.bytes = size;
 		req.name = cfg->volname;
