@@ -10,8 +10,14 @@
 #define STR_HELPER(x) #x
 #define STR(x) STR_HELPER(x)
 
+#if defined(VERSION_SUBLEVEL) && VERSION_SUBLEVEL > 0
+#define SUBLEVEL_STR "." STR(VERSION_SUBLEVEL)
+#else
+#define SUBLEVEL_STR ""
+#endif
+
 #define BANNER "SWUpdate v" \
-	STR(VERSION)"."STR(VERSION_PATCHLEVEL)"."STR(VERSION_SUBLEVEL)"-"STR(VERSION_EXTRAVERSION)
+	STR(VERSION) "." STR(VERSION_PATCHLEVEL) SUBLEVEL_STR STR(VERSION_EXTRAVERSION)
 
 #define SWUPDATE_GENERAL_STRING_SIZE	256
 #define SWUPDATE_UPDATE_DESCRIPTION_STRING_SIZE	512
