@@ -23,3 +23,5 @@ int postupdate(struct swupdate_cfg *swcfg, const char *info);
 int preupdatecmd(struct swupdate_cfg *swcfg);
 int run_prepost_scripts(struct imglist *list, script_fn type);
 void cleanup_files(struct swupdate_cfg *software);
+int update_installed_image_version(struct swver *sw_ver_list,
+		struct img_type *img);
