@@ -10,14 +10,12 @@
 #include <assert.h>
 #include <stdbool.h>
 #include <json-c/json.h>
-#ifdef CONFIG_LIBCONFIG
 #include <libconfig.h>
 #define LIBCONFIG_VERSION ((LIBCONFIG_VER_MAJOR << 16) | \
 	(LIBCONFIG_VER_MINOR << 8) | LIBCONFIG_VER_REVISION)
 #if LIBCONFIG_VERSION < 0x10500
 #define config_setting_lookup config_lookup_from
 #endif
-#endif
 
 typedef enum {
 	LIBCFG_PARSER,
@@ -50,6 +48,8 @@ char *json_get_data_url(json_object *json_root, const char *key);
  * Parselib interface
  */
 bool is_field_numeric(parsertype p, void *e, const char *path);
+bool is_field_bool(parsertype p, void *e, const char *path);
+bool is_field_string(parsertype p, void *e, const char *path);
 const char *get_field_string(parsertype p, void *e, const char *path);
 void get_field_string_with_size(parsertype p, void *e, const char *path,
 				char *d, size_t n);
