@@ -2,7 +2,7 @@
  * Author: Christian Storm
  * Copyright (C) 2016, Siemens AG
  *
- * SPDX-License-Identifier:     GPL-2.0-or-later
+ * SPDX-License-Identifier:     GPL-2.0-only
  */
 
 #pragma once
@@ -19,17 +19,12 @@
 
 /* (Persistent) Update State Management Functions.
  *
- * Suricatta may persistently store the update status to communicate it to the
- * server instance after, e.g., a successful reboot into the new firmware. The
- * `{save,read,reset}_state()` functions are called by a server implementation
- * to persistently manage the update state via, e.g., U-Boot's environment.
+ * The SWUpdate core or a module such as suricatta may want to persistently
+ * store the update status to communicate it to the server instance after,
+ * e.g., a successful reboot into the new firmware.
+ * The `{save,get}_state()` functions are called to manage the update status
+ * via, e.g., U-Boot's environment.
  *
- * Besides suricatta, this mechanism is also used by SWUpdate's core for
- * setting an update transaction marker, i.e., the bootloader environment
- * variable BOOTVAR_TRANSACTION (default: "recovery_status") is set to
- * "in_progress" prior to an update operation and either unset or set to
- * "failed" after the update operation, depending on whether an sw-description's
- * "bootloader_transaction_marker" property is true which is the default.
  */
 
 typedef enum {
@@ -63,8 +58,5 @@ static inline char* get_state_string(update_state_t state) {
 	return (char*)"<nil>";
 }
 
-server_op_res_t save_state(char *key, update_state_t value);
-server_op_res_t save_state_string(char *key, update_state_t value);
-server_op_res_t read_state(char *key, update_state_t *value);
-server_op_res_t unset_state(char *key);
+int save_state(update_state_t value);
 update_state_t get_state(void);
