@@ -23,6 +23,7 @@
 #include "swupdate_status.h"
 #include "swupdate_dict.h"
 #include "compat.h"
+#include "swupdate_aes.h"
 
 #define NOTIFY_BUF_SIZE 	2048
 #define ENOMEM_ASPRINTF		-1
@@ -61,6 +62,7 @@ enum compression_type {
   COMPRESSED_FALSE,
   COMPRESSED_TRUE,
   COMPRESSED_ZLIB,
+  COMPRESSED_XZ,
   COMPRESSED_ZSTD,
 };
 
@@ -91,6 +93,8 @@ struct swupdate_copy {
 	/* encryption */
 	bool encrypted;
 	const char *imgivt;
+	const char *imgaes;
+	cipher_t cipher;
 };
 
 /*
@@ -288,10 +292,12 @@ void set_fwenv_config(const char *fname);
 
 /* Decryption key functions */
 int load_decryption_key(char *fname);
-unsigned char *get_aes_key(void);
-char get_aes_keylen(void);
+char *swupdate_get_decrypt_key(void);
+char swupdate_get_decrypt_keylen(void);
 unsigned char *get_aes_ivt(void);
 int set_aes_key(const char *key, const char *ivt);
+int set_filename_as_key(const char *fname, cipher_t cipher);
+cipher_t swupdate_get_decrypt_cipher(void);
 
 /* Getting global information */
 int get_install_info(char *buf, size_t len);
@@ -300,9 +306,11 @@ void get_install_swset(char *buf, size_t len);
 void get_install_running_mode(char *buf, size_t len);
 bool is_dryrun_install(void);
 char *get_root_device(void);
+char **parse_linux_cmdline(void);
 
 /* Setting global information */
-void set_version_range(const char *minversion,
+int set_version_range(const char *updatetype,
+			const char *minversion,
 			const char *maxversion,
 			const char *current);
 
@@ -328,3 +336,12 @@ char *swupdate_time_iso8601(struct timeval *tv);
 /* eMMC functions */
 int emmc_write_bootpart(int fd, int bootpart);
 int emmc_get_active_bootpart(int fd);
+
+/* used to compare if an attribute is set to enabled or disabled */
+
+static inline bool is_enabled_or_disabled(const char *s) {
+	return (!(strcmp(s, "enabled") && strcmp(s, "disabled")));
+}
+static inline bool is_enabled(const char *s) {
+	return (!strcmp(s, "enabled"));
+}
