@@ -17,6 +17,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <strings.h>
 #include <unistd.h>
 #include <inttypes.h>
 #include <stdbool.h>
@@ -240,7 +241,7 @@ static int mg_check_digest_auth(struct mg_str method, struct mg_str uri,
 			mg_strcmp(auth_domain, mg_str(f_domain)) == 0) {
 			/* Username and domain matched, check the password */
 			mg_mkmd5resp(method, uri, mg_str_s(f_ha1), nonce, nc, cnonce, qop, exp_resp);
-			return strncmp(response.buf, exp_resp, strlen(exp_resp)) == 0;
+			return strncasecmp(response.buf, exp_resp, strlen(exp_resp)) == 0;
 		}
 	}
 
@@ -691,7 +692,11 @@ static void ev_handler(struct mg_connection *nc, int ev, void *ev_data)
 			websocket_handler(nc, ev_data);
 		else if (mg_match(hm->uri, mg_str("#/restart"), NULL))
 			restart_handler(nc, ev_data);
-		else
+	        else if (mg_match(hm->uri, mg_str("#/upload"), NULL)) {
+			nc->pfn = upload_handler;
+			nc->pfn_data = NULL;
+			multipart_upload_handler(nc, ev, hm);
+		} else
 			mg_http_serve_dir(nc, ev_data, &s_http_server_opts);
 	} else if (nc->data[0] != 'M' && nc->data[0] != 'W' && ev == MG_EV_READ) {
 		struct mg_http_message hm;
