@@ -20,6 +20,7 @@
  */
 
 #include "mongoose_multipart.h"
+#include <strings.h>
 
 enum mg_http_multipart_stream_state {
 	MPS_BEGIN,
@@ -203,7 +204,7 @@ static int mg_http_multipart_process_boundary(struct mg_connection *c) {
 		   (line_len = mg_get_line_len(block_begin, data_size)) != 0) {
 		mp_stream->len -= (line_len + 2);
 		if (line_len > sizeof(CONTENT_DISPOSITION) &&
-			strncmp(block_begin, CONTENT_DISPOSITION,
+			strncasecmp(block_begin, CONTENT_DISPOSITION,
 						sizeof(CONTENT_DISPOSITION) - 1) == 0) {
 			struct mg_str header;
 
@@ -219,7 +220,7 @@ static int mg_http_multipart_process_boundary(struct mg_connection *c) {
 			continue;
 		}
 
-		if (line_len == 2 && strncmp(block_begin, "\r\n", 2) == 0) {
+		if (line_len == 2 && strncasecmp(block_begin, "\r\n", 2) == 0) {
 			if (mp_stream->processing_part != 0) {
 				mg_http_multipart_call_handler(c, MG_EV_HTTP_PART_END, NULL, 0);
 			}
@@ -323,7 +324,7 @@ void multipart_upload_handler(struct mg_connection *c, int ev, void *ev_data)
 	struct mg_str *s;
 
 	if (mp_stream != NULL && mp_stream->boundary.len != 0) {
-		if (ev == MG_EV_READ || (ev == MG_EV_POLL && mp_stream->data_avail)) {
+		if (ev == MG_EV_READ || ev == MG_EV_HTTP_MSG || (ev == MG_EV_POLL && mp_stream->data_avail)) {
 			mg_http_multipart_continue(c);
 		} else if (ev == MG_EV_CLOSE) {
 			/*
@@ -336,7 +337,7 @@ void multipart_upload_handler(struct mg_connection *c, int ev, void *ev_data)
 		return;
 	}
 
-	if (ev == MG_EV_READ) {
+	if (ev == MG_EV_READ || ev == MG_EV_HTTP_MSG) {
 		if(mg_strcasecmp(hm->method, mg_str("POST")) != 0) {
 			mg_http_reply(c, 405, "", "%s", "Method Not Allowed\n");
 			c->is_draining = 1;
