@@ -24,6 +24,7 @@
 #include "parselib.h"
 #include "parsers.h"
 #include "swupdate_dict.h"
+#include "swupdate_aes.h"
 #include "lua_util.h"
 
 #define MODULE_NAME	"PARSER"
@@ -188,6 +189,13 @@ static bool get_common_fields(parsertype p, void *cfg, struct swupdate_cfg *swcf
 		TRACE("Description %s", swcfg->description);
 	}
 
+	swcfg->update_type_name[0] = '\0';
+
+	if((setting = find_node(p, cfg, "update-type", swcfg)) != NULL) {
+		GET_FIELD_STRING(p, setting, NULL, swcfg->update_type_name);
+		TRACE("Update Type set to %s", swcfg->update_type_name);
+	}
+
 	if(swcfg->no_state_marker) {
 		swcfg->bootloader_state_marker = false;
 	} else {
@@ -213,12 +221,29 @@ static bool get_common_fields(parsertype p, void *cfg, struct swupdate_cfg *swcf
 	/*
 	 * As default, reboot is initiated
 	 */
-	swcfg->reboot_required = true;
+	swcfg->reboot_enabled = REBOOT_UNSET;
 	if((setting = find_node(p, cfg, "reboot", swcfg)) != NULL) {
-		GET_FIELD_BOOL(p, setting, NULL, &swcfg->reboot_required);
+		if (is_field_bool(p, setting, NULL)) {
+			bool must_reboot = true;
+			GET_FIELD_BOOL(p, setting, NULL, &must_reboot);
+			swcfg->reboot_enabled = must_reboot ? REBOOT_ENABLED : REBOOT_DISABLED;
+		} else if (is_field_string(p, setting, NULL)) {
+			char tmp[SWUPDATE_GENERAL_STRING_SIZE] = "";
+			GET_FIELD_STRING(p, setting, NULL, tmp);
+
+			if (tmp[0] != '\0') {
+				if (!is_enabled_or_disabled(tmp)) {
+					WARN("Possible mismatch for reboot attribute, it is neither enabled nor disabled");
+				} else if (is_enabled(tmp)) {
+					swcfg->reboot_enabled = REBOOT_ENABLED;
+				} else {
+					swcfg->reboot_enabled = REBOOT_DISABLED;
+				}
+			}
+		}
 	}
 
-	TRACE("reboot_required %d", swcfg->reboot_required);
+	TRACE("reboot_enabled %d", swcfg->reboot_enabled != REBOOT_DISABLED);
 
 	/*
 	 * Check if SWU should be cached
@@ -396,10 +421,48 @@ static int run_embscript(parsertype p, void *elem, struct img_type *img,
 	return lua_parser_fn(L, embfcn, img);
 }
 
+static void get_ivt_value(parsertype p, void *elem, char *ivt_ascii)
+{
+	size_t ivtlen;
+	const char *s = NULL;
+
+	s = get_field_string(p, elem, "ivt");
+	if (s) {
+		ivtlen = strnlen(s, SWUPDATE_GENERAL_STRING_SIZE);
+		if (ivtlen != (AES_BLK_SIZE * 2)) {
+			ERROR("Invalid ivt length");
+			return;
+		}
+		strncpy(ivt_ascii, s, ivtlen);
+	}
+}
+
+static void get_aes_value(parsertype p, void *elem, char *aes_ascii)
+{
+	size_t keylen;
+	const char *s = NULL;
+	s = get_field_string(p, elem, "aes-key");
+	if (s) {
+		keylen = strnlen(s, SWUPDATE_GENERAL_STRING_SIZE);
+
+		switch (keylen) {
+		case AES_128_KEY_LEN * 2:
+		case AES_192_KEY_LEN * 2:
+		case AES_256_KEY_LEN * 2:
+			// valid hex string size for AES 128/192/256
+			break;
+		default:
+			ERROR("Invalid aes-key length");
+			return;
+		}
+		get_field_string_with_size(p, elem, "aes-key", aes_ascii, keylen);
+	}
+}
+
 static int parse_common_attributes(parsertype p, void *elem, struct img_type *image, struct swupdate_cfg *cfg)
 {
 	char seek_str[MAX_SEEK_STRING_SIZE];
-	const char* compressed;
+	const char *compressed, *encrypted;
 	unsigned long offset = 0;
 
 	/*
@@ -441,6 +504,8 @@ static int parse_common_attributes(parsertype p, void *elem, struct img_type *im
 	if ((compressed = get_field_string(p, elem, "compressed")) != NULL) {
 		if (!strcmp(compressed, "zlib")) {
 			image->compressed = COMPRESSED_ZLIB;
+		} else if (!strcmp(compressed, "xz")) {
+			image->compressed = COMPRESSED_XZ;
 		} else if (!strcmp(compressed, "zstd")) {
 			image->compressed = COMPRESSED_ZSTD;
 		} else {
@@ -456,8 +521,16 @@ static int parse_common_attributes(parsertype p, void *elem, struct img_type *im
 	GET_FIELD_BOOL(p, elem, "preserve-attributes", &image->preserve_attributes);
 	GET_FIELD_BOOL(p, elem, "install-if-different", &image->id.install_if_different);
 	GET_FIELD_BOOL(p, elem, "install-if-higher", &image->id.install_if_higher);
-	GET_FIELD_BOOL(p, elem, "encrypted", &image->is_encrypted);
-	GET_FIELD_STRING(p, elem, "ivt", image->ivt_ascii);
+
+	if ((encrypted = get_field_string(p, elem, "encrypted")) != NULL) {
+		image->is_encrypted = true;
+		image->cipher = map_name_cipher(encrypted);
+	} else {
+		GET_FIELD_BOOL(p, elem, "encrypted", &image->is_encrypted);
+		image->cipher = AES_CBC;
+	}
+	get_ivt_value(p, elem, image->ivt_ascii);
+	get_aes_value(p, elem, image->aes_ascii);
 
 	if (is_image_installed(&cfg->installed_sw_list, image)) {
 		image->skip = SKIP_SAME;
@@ -1042,7 +1115,6 @@ static int parser(parsertype p, void *cfg, struct swupdate_cfg *swcfg)
 	return ret;
 }
 
-#ifdef CONFIG_LIBCONFIG
 int parse_cfg(struct swupdate_cfg *swcfg, const char *filename, char **error)
 {
 	config_t cfg;
@@ -1073,14 +1145,6 @@ int parse_cfg(struct swupdate_cfg *swcfg, const char *filename, char **error)
 
 	return ret;
 }
-#else
-int parse_cfg(struct swupdate_cfg __attribute__((__unused__)) *swcfg,
-	      const char __attribute__((__unused__)) *filename,
-	      char __attribute__((__unused__)) **error)
-{
-	return -1;
-}
-#endif
 
 #define JSON_OBJECT_FREED 1
 
