@@ -23,7 +23,7 @@
 #include <stddef.h>
 #include <cmocka.h>
 
-#include "sslapi.h"
+#include "swupdate_crypto.h"
 #include "swupdate.h"
 
 #define DATADIR "test/data/"
